@@ -1,6 +1,6 @@
 package ZMQ::FFI;
 {
-  $ZMQ::FFI::VERSION = '0.02';
+  $ZMQ::FFI::VERSION = '0.03';
 }
 # ABSTRACT: zeromq bindings using libffi and FFI::Raw
 
@@ -33,7 +33,7 @@ ZMQ::FFI - zeromq bindings using libffi and FFI::Raw
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -142,6 +142,7 @@ version 0.02
     use ZMQ::FFI;
     use ZMQ::FFI::Constants qw(ZMQ_PUSH ZMQ_PULL);
     use AnyEvent;
+    use EV;
 
     my $endpoint = "ipc://zmq-ffi-$$";
     my $ctx      = ZMQ::FFI->new();
@@ -321,7 +322,7 @@ associated with the option value in the zeromq API (C<zmq_getsockopt> man page)
 
 =head2 set($option, $option_type, $option_value)
 
-    $socket->set(ZMQ_LINGER, 'int', 42)
+    $socket->set(ZMQ_IDENTITY, 'binary', 'foo')
 
 set the socket option to the specified value. C<$option_type> is the type
 associated with the option value in the zeromq API (C<zmq_setsockopt> man page)
@@ -331,6 +332,14 @@ associated with the option value in the zeromq API (C<zmq_setsockopt> man page)
 close the underlying zmq socket. This is called automatically when the object
 goes out of scope
 
+=head1 ERROR HANDLING
+
+ZMQ::FFI checks the return codes of underlying zmq functions for you, and in the
+case of an error it will die with the plain english system error message.
+
+    $ctx->socket(-1);
+    # dies with 'zmq_socket: Invalid argument'
+
 =head1 SEE ALSO
 
 =over 4
